SMB Exceptions — pysmb 1.1.0 documentation

### Navigation

- index
- next |
- previous |
- pysmb 1.1.0 documentation »

# SMB Exceptions

class `smb.base.` `SMBTimeout`

  Raised when a timeout has occurred while waiting for a response or for a SMB/CIFS operation to complete.

class `smb.base.` `NotReadyError`

  Raised when SMB connection is not ready (i.e. not authenticated or authentication failed)

class `smb.base.` `NotConnectedError`

  Raised when underlying SMB connection has been disconnected or not connected yet

class `smb.smb_structs.` `UnsupportedFeature`

  Raised when an supported feature is present/required in the protocol but is not currently supported by pysmb

class `smb.smb_structs.` `ProtocolError`(message, data_buf=None, smb_message=None)

class `smb.smb_structs.` `OperationFailure`(message, smb_messages)

### Navigation

- index
- next |
- previous |
- pysmb 1.1.0 documentation »